# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/rugbypy',
                'doc_host': 'https://seanyboi.github.io',
                'git_url': 'https://github.com/seanyboi/rugbypy',
                'lib_path': 'rugbypy'},
  'syms': { 'rugbypy.match': { 'rugbypy.match.fetch_match_details': ('match.html#fetch_match_details', 'rugbypy/match.py'),
                               'rugbypy.match.fetch_matches': ('match.html#fetch_matches', 'rugbypy/match.py')},
            'rugbypy.player': {'rugbypy.player.fetch_player_stats': ('player.html#fetch_player_stats', 'rugbypy/player.py')},
            'rugbypy.team': {'rugbypy.team.fetch_team_stats': ('team.html#fetch_team_stats', 'rugbypy/team.py')}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/team.ipynb.

# %% auto 0
__all__ = ['fetch_team_stats']

# %% ../nbs/team.ipynb 4
import pandas as pd
import typing
import requests

# %% ../nbs/team.ipynb 5
def fetch_team_stats(team_id: str, date: typing.Optional[str] = None):
    """
    Fetches all team stats for a particular team or if a date is passed then just for a particular game
    """
    if date:
        print(f"Fetching team stats for team_id:{team_id} on date:{date}...")
    else:
        print(f"Fetching all team stats for team_id:{team_id}...")
    try:
        if date:
            team_url = f"https://github.com/seanyboi/rugbydata/blob/main/data/team/{team_id}/{date}.parquet?raw=true"
            team_stats = pd.read_parquet(team_url, engine="pyarrow")
            return team_stats
        else:
            team_url = (
                f"https://github.com/seanyboi/rugbydata/blob/main/data/team/{team_id}"
            )
            path = requests.get(team_url)
            urls = [
                f"https://github.com/seanyboi/rugbydata/blob/main/{p['path']}?raw=true"
                for p in path.json()["payload"]["tree"]["items"]
            ]
            team_stats = pd.concat((pd.read_parquet(u, engine="pyarrow") for u in urls))
            return team_stats
    except Exception as e:
        print(
            f"No team stats for {team_id} because the team id does not exist. Please raise an issue! - {e}"
        )



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/player.ipynb.

# %% auto 0
__all__ = ['fetch_player_stats']

# %% ../nbs/player.ipynb 4
import pandas as pd
import requests
import typing

# %% ../nbs/player.ipynb 5
def fetch_player_stats(player_id: str, date: typing.Optional[str] = None):
    """
    Fetches all player stats for a particular player or if a date is passed then just for a particular game.
    """
    if date:
        print(f"Fetching player stats for player_id:{player_id} on date:{date}...")
    else:
        print(f"Fetching all player stats for player_id:{player_id}...")
    try:
        if date:
            player_url = f"https://github.com/seanyboi/rugbydata/blob/main/data/player/{player_id}/{date}"
            path = requests.get(player_url)
            urls = [
                f"https://github.com/seanyboi/rugbydata/blob/main/{p['path']}?raw=true"
                for p in path.json()["payload"]["tree"]["items"]
            ]
            player_stats = pd.concat(
                (pd.read_parquet(u, engine="pyarrow") for u in urls)
            )
            return player_stats
        else:
            player_url = f"https://github.com/seanyboi/rugbydata/blob/main/data/player/{player_id}"
            path = requests.get(player_url)
            date_urls = [
                f"https://github.com/seanyboi/rugbydata/blob/main/{p['path']}"
                for p in path.json()["payload"]["tree"]["items"]
            ]
            player_urls = [requests.get(url) for url in date_urls]
            player_urls = [
                p.json()["payload"]["tree"]["items"][0]["path"] for p in player_urls
            ]
            player_stats_url = [
                f"https://github.com/seanyboi/rugbydata/blob/main/{p}?raw=true"
                for p in player_urls
            ]
            player_stats = pd.concat(
                (pd.read_parquet(u, engine="pyarrow") for u in player_stats_url)
            )
            return player_stats
    except Exception as e:
        print(
            f"No player stats for {player_id} because the player id does not exist. Please raise an issue! - {e}"
        )



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/match.ipynb.

# %% auto 0
__all__ = ['fetch_matches', 'fetch_match_details']

# %% ../nbs/match.ipynb 4
import pandas as pd

# %% ../nbs/match.ipynb 5
def fetch_matches(date: str):
    """Fetches all match information on a particular date that includes: \n
    * match_id \n
    * competition_id \n
    * home_team_id \n
    * away_team_id
    """

    print(f"Fetching matches on date:{date}...")
    try:
        date_url = f"https://github.com/seanyboi/rugbydata/blob/main/data/dates/{date}.parquet?raw=true"
        matches = pd.read_parquet(date_url, engine="pyarrow")
        matches = matches.assign(date=date)
        return matches
    except Exception as e:
        print(
            f"No match information for matches played on {date} either because no matches took place or rugbypy does not have access to the match data - {e}. Please raise if neither."
        )

# %% ../nbs/match.ipynb 7
def fetch_match_details(match_id: str):
    """Fetches match data for a certain match_id"""
    print(f"Fetching match details for match_id:{match_id}...")
    try:
        match_url = f"https://github.com/seanyboi/rugbydata/blob/main/data/match/{match_id}.parquet?raw=true"
        matches = pd.read_parquet(match_url, engine="pyarrow")
        return matches
    except Exception as e:
        print(f"Error fetching match data - {e}. Please raise an issue!")
